powered by
Calculates the harmonic mean (the reciprocal of the arithmetic mean of the reciprocals of n values).
HarmonicMean(x)
Vector of n values whose harmonic mean is to be calculated.
The harmonic mean of x.
Ruscio et al. (2012)
# NOT RUN { HarmonicMean(c(1, 3, 9, 27, 81)) # }
Run the code above in your browser using DataLab